Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1284)

Unified Diff: content/browser/service_worker/service_worker_context_core.h

Issue 2751343002: Adds a basic offline check to InstallableManager. (Closed)
Patch Set: Updated tests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_context_core.h
diff --git a/content/browser/service_worker/service_worker_context_core.h b/content/browser/service_worker/service_worker_context_core.h
index bb1fc8993cc8fca8c8472648306c06ccd72031bb..c837b46689afe8196daab3c02088d13068dc404a 100644
--- a/content/browser/service_worker/service_worker_context_core.h
+++ b/content/browser/service_worker/service_worker_context_core.h
@@ -283,11 +283,11 @@ class CONTENT_EXPORT ServiceWorkerContextCore
// Determines if there is a ServiceWorker registration that matches |url|, and
// if |other_url| falls inside the scope of the same registration. See
- // ServiceWorkerContext::CheckHasServiceWorker for more details.
- void CheckHasServiceWorker(
+ // ServiceWorkerContext::CheckServiceWorkerStatus for more details.
+ void CheckServiceWorkerStatus(
const GURL& url,
const GURL& other_url,
- const ServiceWorkerContext::CheckHasServiceWorkerCallback callback);
+ const ServiceWorkerContext::CheckServiceWorkerStatusCallback callback);
void UpdateVersionFailureCount(int64_t version_id,
ServiceWorkerStatusCode status);
@@ -337,13 +337,13 @@ class CONTENT_EXPORT ServiceWorkerContextCore
ServiceWorkerStatusCode status,
const std::vector<ServiceWorkerRegistrationInfo>& registrations);
- void DidFindRegistrationForCheckHasServiceWorker(
+ void DidFindRegistrationForCheckServiceWorkerStatus(
const GURL& other_url,
- const ServiceWorkerContext::CheckHasServiceWorkerCallback callback,
+ const ServiceWorkerContext::CheckServiceWorkerStatusCallback callback,
ServiceWorkerStatusCode status,
scoped_refptr<ServiceWorkerRegistration> registration);
- void OnRegistrationFinishedForCheckHasServiceWorker(
- const ServiceWorkerContext::CheckHasServiceWorkerCallback callback,
+ void OnRegistrationFinishedForCheckServiceWorkerStatus(
+ const ServiceWorkerContext::CheckServiceWorkerStatusCallback callback,
scoped_refptr<ServiceWorkerRegistration> registration);
// It's safe to store a raw pointer instead of a scoped_refptr to |wrapper_|

Powered by Google App Engine
This is Rietveld 408576698